<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package minimalblog
 */
?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">
	<?php
	wp_head();
	global $wp_query;
	?>
</head>
<body <?php body_class(); ?>>
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'minimalblog' ); ?></a>
	<?php
	if ( get_theme_mod( 'prealoader_on_off', 'false' ) == true ) {
		?>
			<div id="preloader" style="background-image: url(<?php echo esc_url( get_theme_mod( 'prealoader_image' ) ); ?>);"></div>
		<?php
	}
	$getlayout = get_theme_mod( 'minimalblog_body_layout', 'fulid' );
	$class = '';
	if ( 'box' == $getlayout ) {
		$class = ' boxlayout';
	}
	?>
<div id="page" class="site<?php echo esc_attr( $class ); ?>">
<?php
$getheaderlayout = get_theme_mod( 'header_layout', 'one' );
get_template_part( 'template-parts/header', $getheaderlayout );
$headerimage = ( has_header_image() ? get_header_image() : '' );
$page_main_title = wp_title( '', false );
if ( is_search() ) {
	$page_main_title = sprintf( esc_html__( '%1$s Search Results for: %2$s', 'minimalblog' ), $wp_query->found_posts, '<span>' . get_search_query() . '</span>' );
} elseif ( is_home() ) {
	$page_main_title = get_theme_mod( 'blog_header_custom_title', __( 'Our Awesome Blog', 'minimalblog' ) );
}
if ( is_page_template( array( 'blankpage.php', 'frontpage.php' ) ) ) {
	$pagebannershow = false;
} else {
	$pagebannershow = true;
}
if ( $pagebannershow === true ) :
	?>
 <div class="page-banner-area" style="background-image: url(<?php echo esc_url( $headerimage ); ?>);">
	<div class="container">
		<div class="row">
			<div class="col-md-12 text-center">
				<div class="page-banner-text">
					<?php
					if ( is_author() ) {
						wp_kses_post( minimalblog_author_vcard() );
					} elseif ( is_archive() ) {
						echo '<h1 class="page-title">' . wp_kses_post( $page_main_title ) . '</h1>';
						the_archive_description( '<div class="archive-description">', '</div>' );
						?>
						<nav>
							<div class="breadcrumb">
								<?php
								if ( function_exists( 'bcn_display' ) && ! is_front_page() ) {
										bcn_display();
								}
								?>
							</div>
						</nav>
						<?php
					} else {
						?>
					<h1 class="entry-title"><?php echo wp_kses_post( $page_main_title ); ?></h1>
					<nav>
						<div class="breadcrumb">
							<?php
							if ( function_exists( 'bcn_display' ) && ! is_front_page() ) {
									bcn_display();
							}
							?>
						</div>
					</nav>
				<?php } ?>
				</div>
			</div>
		</div>
	</div>
</div>
<?php endif; ?>
<div id="content" class="site-content">
