<?php
/**
 * Template part for displaying posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package minimalblog
 */
?>
<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
	<div class="entry-content">
		<?php
		if ( get_post_format() === 'gallery' ) {
			get_template_part( 'template-parts/post-header/header', 'gallery' );
		} elseif ( get_post_format() === 'audio' ) {
			get_template_part( 'template-parts/post-header/header', 'audio' );
		} elseif ( get_post_format() === 'video' ) {
			get_template_part( 'template-parts/post-header/header', 'video' );
		} else {
			get_template_part( 'template-parts/post-header/header', 'standard' );
		}
		?>
		<div class="blog-meta">
			<ul>
				<li><span class="fa fa-calendar"></span> <?php minimalblog_posted_on(); ?></li>
				<li><a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ); ?>"><span class="fa fa-user"></span> <?php echo esc_html( get_the_author() ); ?></a></li>
				<li><span class="fa fa-comment"></span> <?php minimalblog_comment_popuplink(); ?></li>
				<li><span class="fa fa-list"></span> 
				<?php
				$categories_list = get_the_category_list( esc_html__( ', ', 'minimalblog' ) );
				if ( $categories_list ) {
					/* translators: 1: list of categories. */
					printf( '<span class="cat-links">' . __( 'Posted in %1$s', 'minimalblog' ) . '</span>', $categories_list ); // WPCS: XSS OK.
				}
				?>
				</li>
			</ul>
		</div>
		<?php
		the_content();
		wp_link_pages(
			array(
				'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'minimalblog' ),
				'after'  => '</div>',
			)
		);
		if ( class_exists( 'A2A_SHARE_SAVE_Widget' ) ) :
			?>
		<div class="social-sharea">
			<?php echo wp_kses_post( do_shortcode( '[addtoany]' ) ); ?>
		</div>
		<?php endif; ?>
	</div><!-- .entry-content -->
	<?php if ( get_edit_post_link() ) : ?>
		<footer class="entry-footer">
			<?php
			edit_post_link(
				sprintf(
					wp_kses(
						/* translators: %s: Name of current post. Only visible to screen readers */
						__( 'Edit <span class="screen-reader-text">%s</span>', 'minimalblog' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				),
				'<span class="edit-link">',
				'</span>'
			);
			?>
		</footer><!-- .entry-footer -->
	<?php endif; ?>
	<div class="d-flex justify-content-between minimalblog-share-wrapper">
		<div class="minimalblog-post-share align-self-center">
			<?php
			if (function_exists('minimalblog_social_share')) {
			 	minimalblog_social_share();
			}
			  ?>
		</div>
	</div>
</article><!-- #post-<?php the_ID(); ?> -->
<div class="post-author">
	<div class="author-image">
		<?php
		echo get_avatar( get_the_author_meta( 'ID' ), 96, '', '', null );
		?>
	</div>
	<div class="author-about">
		<h4><?php echo get_the_author_meta( 'nickname' ); ?></h4>
		<p><?php echo get_the_author_meta( 'description' ); ?></p>
		
	</div>
</div>
